@@ -13,7 +13,7 @@
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
 
-Version = '1.2-1'
+Version = '1.3-1'
 
 import os
 import sys
@@ -96,8 +96,7 @@ def checkTactileInstalled():
          return True
      else: 
          return False
-
-         
+        
 def getCurrent():   
      '''Read the values currently in the config file'''
      
@@ -284,10 +283,12 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
         def doRestartHildon(self):
              '''Restart hildon for the settings to take effect.'''
              
-             message = 'INFO: Hildon is being restarted..'
+             message = 'INFO: Hildon is going to be restarted.\nThe application will now exit..'
              showQuickMessage(message)
              
-             os.system('sudo %s/updateTransitions restartHildon' % PathApp)
+             os.system('sudo %s/updateTransitions restartHildon &' % PathApp)
+             sys.exit(1)
+
             
         def doSetCurrent(self):
              ''' Set CURRENT values in the GUI''' 
